extern "C" int console_plugin_startup();
extern "C" int console_plugin_shutdown();
extern "C" int fifo_plugin_startup();
extern "C" int fifo_plugin_shutdown();
extern "C" int filetail_plugin_startup();
extern "C" int filetail_plugin_shutdown();
extern "C" int gnometext_plugin_startup();
extern "C" int gnometext_plugin_shutdown();
extern "C" int graph_plugin_startup();
extern "C" int graph_plugin_shutdown();
extern "C" int process_plugin_startup();
extern "C" int process_plugin_shutdown();
extern "C" int modifier_plugin_startup();
extern "C" int modifier_plugin_shutdown();
extern "C" int networkload_plugin_startup();
extern "C" int networkload_plugin_shutdown();
extern "C" int remote_plugin_startup();
extern "C" int remote_plugin_shutdown();
extern "C" int roottext_plugin_startup();
extern "C" int roottext_plugin_shutdown();
extern "C" int shell_plugin_startup();
extern "C" int shell_plugin_shutdown();
extern "C" int systemload_plugin_startup();
extern "C" int systemload_plugin_shutdown();
extern "C" int consoledump_plugin_startup();
extern "C" int consoledump_plugin_shutdown();

void initialise_builtin_plugins()
{
        console_plugin_startup();
        fifo_plugin_startup();
        filetail_plugin_startup();
#ifdef WITH_X
        gnometext_plugin_startup();
        graph_plugin_startup();
        roottext_plugin_startup();
        shell_plugin_startup();
#endif
        process_plugin_startup();
        modifier_plugin_startup();
        networkload_plugin_startup();
        remote_plugin_startup();
        systemload_plugin_startup();
        consoledump_plugin_startup();
}

void shutdown_builtin_plugins()
{
        console_plugin_shutdown();
        fifo_plugin_shutdown();
        filetail_plugin_shutdown();
#ifdef WITH_X
        gnometext_plugin_shutdown();
        graph_plugin_shutdown();
        roottext_plugin_shutdown();
        shell_plugin_shutdown();
#endif
        process_plugin_shutdown();
        modifier_plugin_shutdown();
        networkload_plugin_shutdown();
        remote_plugin_shutdown();
        systemload_plugin_shutdown();
        consoledump_plugin_shutdown();
}
